@@ -28,6 +28,8 @@ import java.util.Arrays;
 import java.util.HashMap;
 import java.util.Map;
 import junit.framework.TestCase;
+import org.jspecify.annotations.NullUnmarked;
+import org.jspecify.annotations.Nullable;
 
 /**
  * Tests for {@link MoreObjects#toStringHelper(Object)}.
@@ -35,6 +37,7 @@ import junit.framework.TestCase;
  * @author Jason Lee
  */
 @GwtCompatible
+@NullUnmarked
 public class ToStringHelperTest extends TestCase {
 
   @GwtIncompatible // Class names are obfuscated in GWT
@@ -580,7 +583,7 @@ public class ToStringHelperTest extends TestCase {
     String[] strings = {"hello", "world"};
     int[] ints = {2, 42};
     Object[] objects = {"obj"};
-    String[] arrayWithNull = {null};
+    @Nullable String[] arrayWithNull = new @Nullable String[] {null};
     Object[] empty = {};
     String toTest =
         MoreObjects.toStringHelper("TSH")
