@@ -49,7 +49,8 @@ import java.util.Set;
 import junit.framework.Test;
 import junit.framework.TestCase;
 import junit.framework.TestSuite;
-import org.checkerframework.checker.nullness.qual.Nullable;
+import org.jspecify.annotations.NullMarked;
+import org.jspecify.annotations.Nullable;
 
 /**
  * Tests for {@link ImmutableMultiset}.
@@ -57,11 +58,12 @@ import org.checkerframework.checker.nullness.qual.Nullable;
  * @author Jared Levy
  */
 @GwtCompatible(emulated = true)
-@ElementTypesAreNonnullByDefault
+@NullMarked
 public class ImmutableMultisetTest extends TestCase {
 
   @J2ktIncompatible
   @GwtIncompatible // suite // TODO(cpovirk): add to collect/gwt/suites
+  @AndroidIncompatible // test-suite builders
   public static Test suite() {
     TestSuite suite = new TestSuite();
     suite.addTestSuite(ImmutableMultisetTest.class);
@@ -219,8 +221,7 @@ public class ImmutableMultisetTest extends TestCase {
   }
 
   public void testCopyOf_collection_empty() {
-    // "<String>" is required to work around a javac 1.5 bug.
-    Collection<String> c = MinimalCollection.<String>of();
+    Collection<String> c = MinimalCollection.of();
     Multiset<String> multiset = ImmutableMultiset.copyOf(c);
     assertTrue(multiset.isEmpty());
   }
@@ -404,20 +405,20 @@ public class ImmutableMultisetTest extends TestCase {
 
   public void testBuilderAddAllHandlesNullsCorrectly() {
     {
-    ImmutableMultiset.Builder<String> builder = ImmutableMultiset.builder();
+      ImmutableMultiset.Builder<String> builder = ImmutableMultiset.builder();
       assertThrows(NullPointerException.class, () -> builder.addAll((Collection<String>) null));
     }
 
     {
       ImmutableMultiset.Builder<String> builder = ImmutableMultiset.builder();
-    List<@Nullable String> listWithNulls = asList("a", null, "b");
+      List<@Nullable String> listWithNulls = asList("a", null, "b");
       assertThrows(NullPointerException.class, () -> builder.addAll((List<String>) listWithNulls));
     }
 
     {
       ImmutableMultiset.Builder<String> builder = ImmutableMultiset.builder();
-    Multiset<@Nullable String> multisetWithNull =
-        LinkedHashMultiset.create(Arrays.<@Nullable String>asList("a", null, "b"));
+      Multiset<@Nullable String> multisetWithNull =
+          LinkedHashMultiset.create(Arrays.<@Nullable String>asList("a", null, "b"));
       assertThrows(
           NullPointerException.class, () -> builder.addAll((Multiset<String>) multisetWithNull));
     }
