@@ -24,7 +24,8 @@ import com.google.common.annotations.GwtCompatible;
 import com.google.common.annotations.GwtIncompatible;
 import com.google.common.annotations.J2ktIncompatible;
 import com.google.common.testing.SerializableTester;
-import org.checkerframework.checker.nullness.qual.Nullable;
+import org.jspecify.annotations.NullMarked;
+import org.jspecify.annotations.Nullable;
 
 /**
  * Tests common methods in {@link ImmutableTable}
@@ -32,7 +33,7 @@ import org.checkerframework.checker.nullness.qual.Nullable;
  * @author Gregory Kick
  */
 @GwtCompatible(emulated = true)
-@ElementTypesAreNonnullByDefault
+@NullMarked
 public class ImmutableTableTest extends AbstractTableReadTest<Character> {
   @Override
   protected Table<String, Integer, Character> create(@Nullable Object... data) {
@@ -40,7 +41,7 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
     for (int i = 0; i < data.length; i = i + 3) {
       builder.put((String) data[i], (Integer) data[i + 1], (Character) data[i + 2]);
     }
-    return builder.build();
+    return builder.buildOrThrow();
   }
 
   // TODO(b/172823566): Use mainline testToImmutableMap once CollectorTester is usable to java7.
@@ -64,8 +65,8 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
 
   public void testBuilder() {
     ImmutableTable.Builder<Character, Integer, String> builder = new ImmutableTable.Builder<>();
-    assertEquals(ImmutableTable.of(), builder.build());
-    assertEquals(ImmutableTable.of('a', 1, "foo"), builder.put('a', 1, "foo").build());
+    assertEquals(ImmutableTable.of(), builder.buildOrThrow());
+    assertEquals(ImmutableTable.of('a', 1, "foo"), builder.put('a', 1, "foo").buildOrThrow());
     Table<Character, Integer, String> expectedTable = HashBasedTable.create();
     expectedTable.put('a', 1, "foo");
     expectedTable.put('b', 1, "bar");
@@ -73,13 +74,13 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
     Table<Character, Integer, String> otherTable = HashBasedTable.create();
     otherTable.put('b', 1, "bar");
     otherTable.put('a', 2, "baz");
-    assertEquals(expectedTable, builder.putAll(otherTable).build());
+    assertEquals(expectedTable, builder.putAll(otherTable).buildOrThrow());
   }
 
   public void testBuilder_withImmutableCell() {
     ImmutableTable.Builder<Character, Integer, String> builder = new ImmutableTable.Builder<>();
     assertEquals(
-        ImmutableTable.of('a', 1, "foo"), builder.put(immutableCell('a', 1, "foo")).build());
+        ImmutableTable.of('a', 1, "foo"), builder.put(immutableCell('a', 1, "foo")).buildOrThrow());
   }
 
   public void testBuilder_withImmutableCellAndNullContents() {
@@ -126,7 +127,7 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
     holder.string = "bar";
 
     // Make sure it uses the original value.
-    assertEquals(ImmutableTable.of('K', 42, "foo"), builder.build());
+    assertEquals(ImmutableTable.of('K', 42, "foo"), builder.buildOrThrow());
   }
 
   public void testBuilder_noDuplicates() {
@@ -134,7 +135,7 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
         new ImmutableTable.Builder<Character, Integer, String>()
             .put('a', 1, "foo")
             .put('a', 1, "bar");
-    assertThrows(IllegalArgumentException.class, () -> builder.build());
+    assertThrows(IllegalArgumentException.class, () -> builder.buildOrThrow());
   }
 
   public void testBuilder_noNulls() {
@@ -149,7 +150,7 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
     assertEquals(original, copy);
     validateViewOrdering(original, copy);
 
-    Table<R, C, V> built = ImmutableTable.<R, C, V>builder().putAll(original).build();
+    Table<R, C, V> built = ImmutableTable.<R, C, V>builder().putAll(original).buildOrThrow();
     assertEquals(original, built);
     validateViewOrdering(original, built);
   }
@@ -212,7 +213,7 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
             .orderRowsBy(Ordering.natural())
             .orderColumnsBy(Ordering.natural())
             .putAll(table)
-            .build();
+            .buildOrThrow();
     assertThat(copy.rowKeySet()).containsExactly('a', 'b').inOrder();
     assertThat(copy.columnKeySet()).containsExactly(1, 2).inOrder();
     assertThat(copy.values()).containsExactly("baz", "bar", "foo").inOrder();
@@ -232,7 +233,7 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
     builder.put('e', 3, "tub");
     builder.put('r', 4, "foo");
     builder.put('x', 5, "bar");
-    Table<Character, Integer, String> table = builder.build();
+    Table<Character, Integer, String> table = builder.buildOrThrow();
     assertThat(table.rowKeySet()).containsExactly('b', 'c', 'e', 'r', 'x').inOrder();
     assertThat(table.columnKeySet()).containsExactly(0, 1, 2, 3, 4, 5, 7).inOrder();
     assertThat(table.values())
@@ -254,7 +255,7 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
     builder.put('a', 3, "foo");
     builder.put('a', 2, "bar");
     builder.put('a', 1, "baz");
-    Table<Character, Integer, String> table = builder.build();
+    Table<Character, Integer, String> table = builder.buildOrThrow();
     assertThat(table.rowKeySet()).containsExactly('a', 'b', 'c').inOrder();
     assertThat(table.columnKeySet()).containsExactly(1, 2, 3).inOrder();
     assertThat(table.values())
@@ -276,7 +277,7 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
     builder.put('e', 3, "tub");
     builder.put('r', 4, "foo");
     builder.put('x', 5, "bar");
-    Table<Character, Integer, String> table = builder.build();
+    Table<Character, Integer, String> table = builder.buildOrThrow();
     assertThat(table.rowKeySet()).containsExactly('b', 'c', 'e', 'r', 'x').inOrder();
     assertThat(table.column(5).keySet()).containsExactly('e', 'x').inOrder();
   }
@@ -292,7 +293,7 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
     builder.put('a', 3, "foo");
     builder.put('a', 2, "bar");
     builder.put('a', 1, "baz");
-    Table<Character, Integer, String> table = builder.build();
+    Table<Character, Integer, String> table = builder.buildOrThrow();
     assertThat(table.rowKeySet()).containsExactly('a', 'b', 'c').inOrder();
     assertThat(table.column(1).keySet()).containsExactly('a', 'b', 'c').inOrder();
   }
@@ -309,7 +310,7 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
     builder.put('e', 3, "tub");
     builder.put('r', 4, "foo");
     builder.put('x', 5, "bar");
-    Table<Character, Integer, String> table = builder.build();
+    Table<Character, Integer, String> table = builder.buildOrThrow();
     assertThat(table.columnKeySet()).containsExactly(0, 1, 2, 3, 4, 5, 7).inOrder();
     assertThat(table.row('c').keySet()).containsExactly(0, 3).inOrder();
   }
@@ -325,7 +326,7 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
     builder.put('a', 3, "foo");
     builder.put('a', 2, "bar");
     builder.put('a', 1, "baz");
-    Table<Character, Integer, String> table = builder.build();
+    Table<Character, Integer, String> table = builder.buildOrThrow();
     assertThat(table.columnKeySet()).containsExactly(1, 2, 3).inOrder();
     assertThat(table.row('c').keySet()).containsExactly(1, 2, 3).inOrder();
   }
@@ -343,7 +344,7 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
     builder.put('b', 2, "foo");
     builder.put('b', 1, "bar");
     builder.put('a', 2, "baz");
-    Table<Character, Integer, String> table = builder.build();
+    Table<Character, Integer, String> table = builder.buildOrThrow();
     assertThat(table).isInstanceOf(DenseImmutableTable.class);
     validateReserialization(table);
   }
@@ -354,7 +355,7 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
     builder.put('b', 2, "foo");
     builder.put('b', 1, "bar");
     builder.put('a', 2, "baz");
-    Table<Character, Integer, String> table = builder.build();
+    Table<Character, Integer, String> table = builder.buildOrThrow();
     assertThat(table).isInstanceOf(DenseImmutableTable.class);
     validateReserialization(table);
   }
@@ -365,7 +366,7 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
     builder.put('b', 2, "foo");
     builder.put('b', 1, "bar");
     builder.put('a', 2, "baz");
-    Table<Character, Integer, String> table = builder.build();
+    Table<Character, Integer, String> table = builder.buildOrThrow();
     assertThat(table).isInstanceOf(DenseImmutableTable.class);
     validateReserialization(table);
   }
@@ -377,7 +378,7 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
     builder.put('b', 2, "foo");
     builder.put('b', 1, "bar");
     builder.put('a', 2, "baz");
-    Table<Character, Integer, String> table = builder.build();
+    Table<Character, Integer, String> table = builder.buildOrThrow();
     assertThat(table).isInstanceOf(DenseImmutableTable.class);
     validateReserialization(table);
   }
@@ -389,7 +390,7 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
     builder.put('a', 2, "baz");
     builder.put('c', 3, "cat");
     builder.put('d', 4, "dog");
-    Table<Character, Integer, String> table = builder.build();
+    Table<Character, Integer, String> table = builder.buildOrThrow();
     assertThat(table).isInstanceOf(SparseImmutableTable.class);
     validateReserialization(table);
   }
@@ -402,7 +403,7 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
     builder.put('a', 2, "baz");
     builder.put('c', 3, "cat");
     builder.put('d', 4, "dog");
-    Table<Character, Integer, String> table = builder.build();
+    Table<Character, Integer, String> table = builder.buildOrThrow();
     assertThat(table).isInstanceOf(SparseImmutableTable.class);
     validateReserialization(table);
   }
@@ -415,7 +416,7 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
     builder.put('a', 2, "baz");
     builder.put('c', 3, "cat");
     builder.put('d', 4, "dog");
-    Table<Character, Integer, String> table = builder.build();
+    Table<Character, Integer, String> table = builder.buildOrThrow();
     assertThat(table).isInstanceOf(SparseImmutableTable.class);
     validateReserialization(table);
   }
@@ -429,7 +430,7 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
     builder.put('a', 2, "baz");
     builder.put('c', 3, "cat");
     builder.put('d', 4, "dog");
-    Table<Character, Integer, String> table = builder.build();
+    Table<Character, Integer, String> table = builder.buildOrThrow();
     assertThat(table).isInstanceOf(SparseImmutableTable.class);
     validateReserialization(table);
   }
@@ -451,6 +452,6 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
       builder.put(i, 0, "foo");
       builder.put(0, i, "bar");
     }
-    assertTrue(builder.build() instanceof SparseImmutableTable);
+    assertTrue(builder.buildOrThrow() instanceof SparseImmutableTable);
   }
 }
