@@ -28,7 +28,7 @@ import java.util.Map;
 import java.util.regex.Pattern;
 import java.util.stream.Stream;
 import java.util.stream.StreamSupport;
-import javax.annotation.CheckForNull;
+import org.jspecify.annotations.Nullable;
 
 /**
  * Extracts non-overlapping substrings from an input string, typically by recognizing appearances of
@@ -39,9 +39,9 @@ import javax.annotation.CheckForNull;
  *
  * <p>For example, this expression:
  *
- * <pre>{@code
+ * {@snippet :
  * Splitter.on(',').split("foo,bar,qux")
- * }</pre>
+ * }
  *
  * ... produces an {@code Iterable} containing {@code "foo"}, {@code "bar"} and {@code "qux"}, in
  * that order.
@@ -49,19 +49,19 @@ import javax.annotation.CheckForNull;
  * <p>By default, {@code Splitter}'s behavior is simplistic and unassuming. The following
  * expression:
  *
- * <pre>{@code
+ * {@snippet :
  * Splitter.on(',').split(" foo,,,  bar ,")
- * }</pre>
+ * }
  *
  * ... yields the substrings {@code [" foo", "", "", " bar ", ""]}. If this is not the desired
  * behavior, use configuration methods to obtain a <i>new</i> splitter instance with modified
  * behavior:
  *
- * <pre>{@code
+ * {@snippet :
  * private static final Splitter MY_SPLITTER = Splitter.on(',')
  *     .trimResults()
  *     .omitEmptyStrings();
- * }</pre>
+ * }
  *
  * <p>Now {@code MY_SPLITTER.split("foo,,, bar ,")} returns just {@code ["foo", "bar"]}. Note that
  * the order in which these configuration methods are called is never significant.
@@ -70,12 +70,12 @@ import javax.annotation.CheckForNull;
  * effect on the receiving instance; you must store and use the new splitter instance it returns
  * instead.
  *
- * <pre>{@code
+ * {@snippet :
  * // Do NOT do this
  * Splitter splitter = Splitter.on('/');
  * splitter.trimResults(); // does nothing!
  * return splitter.split("wrong / wrong / wrong");
- * }</pre>
+ * }
  *
  * <p>For separator-based splitters that do not use {@code omitEmptyStrings}, an input string
  * containing {@code n} occurrences of the separator naturally yields an iterable of size {@code n +
@@ -99,7 +99,6 @@ import javax.annotation.CheckForNull;
  * @since 1.0
  */
 @GwtCompatible(emulated = true)
-@ElementTypesAreNonnullByDefault
 public final class Splitter {
   private final CharMatcher trimmer;
   private final boolean omitEmptyStrings;
@@ -138,14 +137,12 @@ public final class Splitter {
    *     separator
    * @return a splitter, with default settings, that uses this matcher
    */
-  public static Splitter on(final CharMatcher separatorMatcher) {
+  public static Splitter on(CharMatcher separatorMatcher) {
     checkNotNull(separatorMatcher);
 
     return new Splitter(
-        new Strategy() {
-          @Override
-          public SplittingIterator iterator(Splitter splitter, final CharSequence toSplit) {
-            return new SplittingIterator(splitter, toSplit) {
+        (splitter, toSplit) ->
+            new SplittingIterator(splitter, toSplit) {
               @Override
               int separatorStart(int start) {
                 return separatorMatcher.indexIn(toSplit, start);
@@ -155,9 +152,7 @@ public final class Splitter {
               int separatorEnd(int separatorPosition) {
                 return separatorPosition + 1;
               }
-            };
-          }
-        });
+            });
   }
 
   /**
@@ -168,16 +163,14 @@ public final class Splitter {
    * @param separator the literal, nonempty string to recognize as a separator
    * @return a splitter, with default settings, that recognizes that separator
    */
-  public static Splitter on(final String separator) {
+  public static Splitter on(String separator) {
     checkArgument(separator.length() != 0, "The separator may not be the empty string.");
     if (separator.length() == 1) {
       return Splitter.on(separator.charAt(0));
     }
     return new Splitter(
-        new Strategy() {
-          @Override
-          public SplittingIterator iterator(Splitter splitter, CharSequence toSplit) {
-            return new SplittingIterator(splitter, toSplit) {
+        (splitter, toSplit) ->
+            new SplittingIterator(splitter, toSplit) {
               @Override
               public int separatorStart(int start) {
                 int separatorLength = separator.length();
@@ -198,9 +191,7 @@ public final class Splitter {
               public int separatorEnd(int separatorPosition) {
                 return separatorPosition + separator.length();
               }
-            };
-          }
-        });
+            });
   }
 
   /**
@@ -219,29 +210,26 @@ public final class Splitter {
   }
 
   /** Internal utility; see {@link #on(Pattern)} instead. */
-  static Splitter onPatternInternal(final CommonPattern separatorPattern) {
+  static Splitter onPatternInternal(CommonPattern separatorPattern) {
     checkArgument(
         !separatorPattern.matcher("").matches(),
         "The pattern may not match the empty string: %s",
         separatorPattern);
 
     return new Splitter(
-        new Strategy() {
-          @Override
-          public SplittingIterator iterator(final Splitter splitter, CharSequence toSplit) {
-            final CommonMatcher matcher = separatorPattern.matcher(toSplit);
-            return new SplittingIterator(splitter, toSplit) {
-              @Override
-              public int separatorStart(int start) {
-                return matcher.find(start) ? matcher.start() : -1;
-              }
+        (splitter, toSplit) -> {
+          CommonMatcher matcher = separatorPattern.matcher(toSplit);
+          return new SplittingIterator(splitter, toSplit) {
+            @Override
+            public int separatorStart(int start) {
+              return matcher.find(start) ? matcher.start() : -1;
+            }
 
-              @Override
-              public int separatorEnd(int separatorPosition) {
-                return matcher.end();
-              }
-            };
-          }
+            @Override
+            public int separatorEnd(int separatorPosition) {
+              return matcher.end();
+            }
+          };
         });
   }
 
@@ -280,14 +268,12 @@ public final class Splitter {
    * @return a splitter, with default settings, that can split into fixed sized pieces
    * @throws IllegalArgumentException if {@code length} is zero or negative
    */
-  public static Splitter fixedLength(final int length) {
+  public static Splitter fixedLength(int length) {
     checkArgument(length > 0, "The length may not be less than 1");
 
     return new Splitter(
-        new Strategy() {
-          @Override
-          public SplittingIterator iterator(final Splitter splitter, CharSequence toSplit) {
-            return new SplittingIterator(splitter, toSplit) {
+        (splitter, toSplit) ->
+            new SplittingIterator(splitter, toSplit) {
               @Override
               public int separatorStart(int start) {
                 int nextChunkStart = start + length;
@@ -298,9 +284,7 @@ public final class Splitter {
               public int separatorEnd(int separatorPosition) {
                 return separatorPosition;
               }
-            };
-          }
-        });
+            });
   }
 
   /**
@@ -381,7 +365,7 @@ public final class Splitter {
    * @param sequence the sequence of characters to split
    * @return an iteration over the segments split from the parameter
    */
-  public Iterable<String> split(final CharSequence sequence) {
+  public Iterable<String> split(CharSequence sequence) {
     checkNotNull(sequence);
 
     return new Iterable<String>() {
@@ -471,13 +455,13 @@ public final class Splitter {
    *
    * <p>Example:
    *
-   * <pre>{@code
+   * {@snippet :
    * String toSplit = " x -> y, z-> a ";
    * Splitter outerSplitter = Splitter.on(',').trimResults();
    * MapSplitter mapSplitter = outerSplitter.withKeyValueSeparator(Splitter.on("->"));
    * Map<String, String> result = mapSplitter.split(toSplit);
    * assertThat(result).isEqualTo(ImmutableMap.of("x ", " y", "z", " a"));
-   * }</pre>
+   * }
    *
    * @since 10.0
    */
@@ -564,9 +548,8 @@ public final class Splitter {
       this.toSplit = toSplit;
     }
 
-    @CheckForNull
     @Override
-    protected String computeNext() {
+    protected @Nullable String computeNext() {
       /*
        * The returned string will be from the end of the last match to the beginning of the next
        * one. nextStart is the start position of the returned substring, while offset is the place
