@@ -36,8 +36,7 @@ import java.util.Collections;
 import java.util.Comparator;
 import java.util.Iterator;
 import java.util.List;
-import javax.annotation.CheckForNull;
-import org.checkerframework.checker.nullness.qual.Nullable;
+import org.jspecify.annotations.Nullable;
 
 /**
  * Provides static methods for working with {@code Collection} instances.
@@ -53,7 +52,6 @@ import org.checkerframework.checker.nullness.qual.Nullable;
  * @since 2.0
  */
 @GwtCompatible
-@ElementTypesAreNonnullByDefault
 public final class Collections2 {
   private Collections2() {}
 
@@ -99,7 +97,7 @@ public final class Collections2 {
    * Delegates to {@link Collection#contains}. Returns {@code false} if the {@code contains} method
    * throws a {@code ClassCastException} or {@code NullPointerException}.
    */
-  static boolean safeContains(Collection<?> collection, @CheckForNull Object object) {
+  static boolean safeContains(Collection<?> collection, @Nullable Object object) {
     checkNotNull(collection);
     try {
       return collection.contains(object);
@@ -112,7 +110,7 @@ public final class Collections2 {
    * Delegates to {@link Collection#remove}. Returns {@code false} if the {@code remove} method
    * throws a {@code ClassCastException} or {@code NullPointerException}.
    */
-  static boolean safeRemove(Collection<?> collection, @CheckForNull Object object) {
+  static boolean safeRemove(Collection<?> collection, @Nullable Object object) {
     checkNotNull(collection);
     try {
       return collection.remove(object);
@@ -154,7 +152,7 @@ public final class Collections2 {
     }
 
     @Override
-    public boolean contains(@CheckForNull Object element) {
+    public boolean contains(@Nullable Object element) {
       if (safeContains(unfiltered, element)) {
         @SuppressWarnings("unchecked") // element is in unfiltered, so it must be an E
         E e = (E) element;
@@ -179,12 +177,12 @@ public final class Collections2 {
     }
 
     @Override
-    public boolean remove(@CheckForNull Object element) {
+    public boolean remove(@Nullable Object element) {
       return contains(element) && unfiltered.remove(element);
     }
 
     @Override
-    public boolean removeAll(final Collection<?> collection) {
+    public boolean removeAll(Collection<?> collection) {
       boolean changed = false;
       Iterator<E> itr = unfiltered.iterator();
       while (itr.hasNext()) {
@@ -198,7 +196,7 @@ public final class Collections2 {
     }
 
     @Override
-    public boolean retainAll(final Collection<?> collection) {
+    public boolean retainAll(Collection<?> collection) {
       boolean changed = false;
       Iterator<E> itr = unfiltered.iterator();
       while (itr.hasNext()) {
@@ -311,7 +309,7 @@ public final class Collections2 {
   }
 
   /** An implementation of {@link Collection#toString()}. */
-  static String toStringImpl(final Collection<?> collection) {
+  static String toStringImpl(Collection<?> collection) {
     StringBuilder sb = newStringBuilderForCollection(collection.size()).append('[');
     boolean first = true;
     for (Object o : collection) {
@@ -367,7 +365,7 @@ public final class Collections2 {
    *
    * <p>Examples:
    *
-   * <pre>{@code
+   * {@snippet :
    * for (List<String> perm : orderedPermutations(asList("b", "c", "a"))) {
    *   println(perm);
    * }
@@ -387,7 +385,7 @@ public final class Collections2 {
    * // -> [2, 1, 1, 2]
    * // -> [2, 1, 2, 1]
    * // -> [2, 2, 1, 1]
-   * }</pre>
+   * }
    *
    * <p><i>Notes:</i> This is an implementation of the algorithm for Lexicographical Permutations
    * Generation, described in Knuth's "The Art of Computer Programming", Volume 4, Chapter 7,
@@ -469,7 +467,7 @@ public final class Collections2 {
     }
 
     @Override
-    public boolean contains(@CheckForNull Object obj) {
+    public boolean contains(@Nullable Object obj) {
       if (obj instanceof List) {
         List<?> list = (List<?>) obj;
         return isPermutation(inputList, list);
@@ -484,7 +482,7 @@ public final class Collections2 {
   }
 
   private static final class OrderedPermutationIterator<E> extends AbstractIterator<List<E>> {
-    @CheckForNull List<E> nextPermutation;
+    @Nullable List<E> nextPermutation;
     final Comparator<? super E> comparator;
 
     OrderedPermutationIterator(List<E> list, Comparator<? super E> comparator) {
@@ -493,8 +491,7 @@ public final class Collections2 {
     }
 
     @Override
-    @CheckForNull
-    protected List<E> computeNext() {
+    protected @Nullable List<E> computeNext() {
       if (nextPermutation == null) {
         return endOfData();
       }
@@ -595,7 +592,7 @@ public final class Collections2 {
     }
 
     @Override
-    public boolean contains(@CheckForNull Object obj) {
+    public boolean contains(@Nullable Object obj) {
       if (obj instanceof List) {
         List<?> list = (List<?>) obj;
         return isPermutation(inputList, list);
@@ -626,8 +623,7 @@ public final class Collections2 {
     }
 
     @Override
-    @CheckForNull
-    protected List<E> computeNext() {
+    protected @Nullable List<E> computeNext() {
       if (j <= 0) {
         return endOfData();
       }
