@@ -31,9 +31,9 @@ import java.util.Comparator;
 import java.util.Iterator;
 import java.util.List;
 import java.util.SortedSet;
-import javax.annotation.CheckForNull;
-import org.checkerframework.checker.nullness.qual.NonNull;
-import org.checkerframework.checker.nullness.qual.Nullable;
+import java.util.stream.Stream;
+import org.jspecify.annotations.NonNull;
+import org.jspecify.annotations.Nullable;
 
 /**
  * An expanded {@code Iterable} API, providing functionality similar to Java 8's powerful <a href=
@@ -87,18 +87,18 @@ import org.checkerframework.checker.nullness.qual.Nullable;
  * transforms it by invoking {@code toString()} on each element, and returns the first 10 elements
  * as a {@code List}:
  *
- * <pre>{@code
+ * {@snippet :
  * ImmutableList<String> results =
  *     FluentIterable.from(database.getClientList())
  *         .filter(Client::isActiveInLastMonth)
  *         .transform(Object::toString)
  *         .limit(10)
  *         .toList();
- * }</pre>
+ * }
  *
  * The approximate stream equivalent is:
  *
- * <pre>{@code
+ * {@snippet :
  * List<String> results =
  *     database.getClientList()
  *         .stream()
@@ -106,13 +106,12 @@ import org.checkerframework.checker.nullness.qual.Nullable;
  *         .map(Object::toString)
  *         .limit(10)
  *         .collect(Collectors.toList());
- * }</pre>
+ * }
  *
  * @author Marcin Mikosik
  * @since 12.0
  */
 @GwtCompatible(emulated = true)
-@ElementTypesAreNonnullByDefault
 public abstract class FluentIterable<E extends @Nullable Object> implements Iterable<E> {
   // We store 'iterable' and use it instead of 'this' to allow Iterables to perform instanceof
   // checks on the _original_ iterable when FluentIterable.from is used.
@@ -141,7 +140,7 @@ public abstract class FluentIterable<E extends @Nullable Object> implements Iter
    * <p><b>{@code Stream} equivalent:</b> {@code iterable.stream()} if {@code iterable} is a {@link
    * Collection}; {@code StreamSupport.stream(iterable.spliterator(), false)} otherwise.
    */
-  public static <E extends @Nullable Object> FluentIterable<E> from(final Iterable<E> iterable) {
+  public static <E extends @Nullable Object> FluentIterable<E> from(Iterable<E> iterable) {
     return (iterable instanceof FluentIterable)
         ? (FluentIterable<E>) iterable
         : new FluentIterable<E>(iterable) {
@@ -275,7 +274,7 @@ public abstract class FluentIterable<E extends @Nullable Object> implements Iter
    * @since 20.0
    */
   public static <T extends @Nullable Object> FluentIterable<T> concat(
-      final Iterable<? extends Iterable<? extends T>> inputs) {
+      Iterable<? extends Iterable<? extends T>> inputs) {
     checkNotNull(inputs);
     return new FluentIterable<T>() {
       @Override
@@ -287,7 +286,7 @@ public abstract class FluentIterable<E extends @Nullable Object> implements Iter
 
   /** Concatenates a varargs array of iterables without making a defensive copy of the array. */
   private static <T extends @Nullable Object> FluentIterable<T> concatNoDefensiveCopy(
-      final Iterable<? extends T>... inputs) {
+      Iterable<? extends T>... inputs) {
     for (Iterable<? extends T> input : inputs) {
       checkNotNull(input);
     }
@@ -357,7 +356,7 @@ public abstract class FluentIterable<E extends @Nullable Object> implements Iter
    *
    * <p><b>{@code Stream} equivalent:</b> {@code stream.anyMatch(Predicate.isEqual(target))}.
    */
-  public final boolean contains(@CheckForNull Object target) {
+  public final boolean contains(@Nullable Object target) {
     return Iterables.contains(getDelegate(), target);
   }
 
@@ -426,11 +425,11 @@ public abstract class FluentIterable<E extends @Nullable Object> implements Iter
    * This does perform a little more work than necessary, so another option is to insert an
    * unchecked cast at some later point:
    *
-   * <pre>
-   * {@code @SuppressWarnings("unchecked") // safe because of ::isInstance check
+   * {@snippet :
+   * @SuppressWarnings("unchecked") // safe because of ::isInstance check
    * ImmutableList<NewType> result =
-   *     (ImmutableList) stream.filter(NewType.class::isInstance).collect(toImmutableList());}
-   * </pre>
+   *     (ImmutableList) stream.filter(NewType.class::isInstance).collect(toImmutableList());
+   * }
    */
   @GwtIncompatible // Class.isInstance
   public final <T> FluentIterable<T> filter(Class<T> type) {
@@ -742,14 +741,14 @@ public abstract class FluentIterable<E extends @Nullable Object> implements Iter
    * map whose key is the result of applying {@code keyFunction} to that value. These entries appear
    * in the same order as they appeared in this fluent iterable. Example usage:
    *
-   * <pre>{@code
+   * {@snippet :
    * Color red = new Color("red", 255, 0, 0);
    * ...
    * FluentIterable<Color> allColors = FluentIterable.from(ImmutableSet.of(red, green, blue));
    *
    * Map<String, Color> colorForName = allColors.uniqueIndex(toStringFunction());
    * assertThat(colorForName).containsEntry("red", red);
-   * }</pre>
+   * }
    *
    * <p>If your index may associate multiple values with each key, use {@link #index(Function)
    * index}.
@@ -845,13 +844,4 @@ public abstract class FluentIterable<E extends @Nullable Object> implements Iter
   public final E get(int position) {
     return Iterables.get(getDelegate(), position);
   }
-
-  /** Function that transforms {@code Iterable<E>} into a fluent iterable. */
-  private static class FromIterableFunction<E extends @Nullable Object>
-      implements Function<Iterable<E>, FluentIterable<E>> {
-    @Override
-    public FluentIterable<E> apply(Iterable<E> fromObject) {
-      return FluentIterable.from(fromObject);
-    }
-  }
 }
