@@ -20,6 +20,7 @@ import static com.google.common.collect.CollectPreconditions.checkEntryNotNull;
 import static com.google.common.collect.CollectPreconditions.checkNonnegative;
 
 import com.google.common.annotations.GwtCompatible;
+import com.google.common.annotations.GwtIncompatible;
 import com.google.common.annotations.J2ktIncompatible;
 import com.google.errorprone.annotations.CanIgnoreReturnValue;
 import com.google.errorprone.annotations.DoNotCall;
@@ -33,8 +34,7 @@ import java.util.function.BinaryOperator;
 import java.util.function.Function;
 import java.util.stream.Collector;
 import java.util.stream.Collectors;
-import javax.annotation.CheckForNull;
-import org.checkerframework.checker.nullness.qual.Nullable;
+import org.jspecify.annotations.Nullable;
 
 /**
  * A {@link BiMap} whose contents will never change, with many other important properties detailed
@@ -44,7 +44,6 @@ import org.checkerframework.checker.nullness.qual.Nullable;
  * @since 2.0
  */
 @GwtCompatible(serializable = true, emulated = true)
-@ElementTypesAreNonnullByDefault
 public abstract class ImmutableBiMap<K, V> extends ImmutableMap<K, V> implements BiMap<K, V> {
 
   /**
@@ -154,6 +153,7 @@ public abstract class ImmutableBiMap<K, V> extends ImmutableMap<K, V> implements
     return new RegularImmutableBiMap<K, V>(
         new Object[] {k1, v1, k2, v2, k3, v3, k4, v4, k5, v5, k6, v6}, 6);
   }
+
   /**
    * Returns an immutable map containing the given entries, in order.
    *
@@ -172,6 +172,7 @@ public abstract class ImmutableBiMap<K, V> extends ImmutableMap<K, V> implements
     return new RegularImmutableBiMap<K, V>(
         new Object[] {k1, v1, k2, v2, k3, v3, k4, v4, k5, v5, k6, v6, k7, v7}, 7);
   }
+
   /**
    * Returns an immutable map containing the given entries, in order.
    *
@@ -206,6 +207,7 @@ public abstract class ImmutableBiMap<K, V> extends ImmutableMap<K, V> implements
     return new RegularImmutableBiMap<K, V>(
         new Object[] {k1, v1, k2, v2, k3, v3, k4, v4, k5, v5, k6, v6, k7, v7, k8, v8}, 8);
   }
+
   /**
    * Returns an immutable map containing the given entries, in order.
    *
@@ -243,6 +245,7 @@ public abstract class ImmutableBiMap<K, V> extends ImmutableMap<K, V> implements
     return new RegularImmutableBiMap<K, V>(
         new Object[] {k1, v1, k2, v2, k3, v3, k4, v4, k5, v5, k6, v6, k7, v7, k8, v8, k9, v9}, 9);
   }
+
   /**
    * Returns an immutable map containing the given entries, in order.
    *
@@ -331,14 +334,14 @@ public abstract class ImmutableBiMap<K, V> extends ImmutableMap<K, V> implements
    * A builder for creating immutable bimap instances, especially {@code public static final} bimaps
    * ("constant bimaps"). Example:
    *
-   * <pre>{@code
+   * {@snippet :
    * static final ImmutableBiMap<String, Integer> WORD_TO_INT =
    *     new ImmutableBiMap.Builder<String, Integer>()
    *         .put("one", 1)
    *         .put("two", 2)
    *         .put("three", 3)
    *         .buildOrThrow();
-   * }</pre>
+   * }
    *
    * <p>For <i>small</i> immutable bimaps, the {@code ImmutableBiMap.of()} methods are even more
    * convenient.
@@ -580,8 +583,7 @@ public abstract class ImmutableBiMap<K, V> extends ImmutableMap<K, V> implements
   @Deprecated
   @Override
   @DoNotCall("Always throws UnsupportedOperationException")
-  @CheckForNull
-  public final V forcePut(K key, V value) {
+  public final @Nullable V forcePut(K key, V value) {
     throw new UnsupportedOperationException();
   }
 
@@ -604,7 +606,7 @@ public abstract class ImmutableBiMap<K, V> extends ImmutableMap<K, V> implements
       return new Builder<>(size);
     }
 
-    private static final long serialVersionUID = 0;
+    @GwtIncompatible @J2ktIncompatible private static final long serialVersionUID = 0;
   }
 
   @Override
@@ -623,7 +625,7 @@ public abstract class ImmutableBiMap<K, V> extends ImmutableMap<K, V> implements
    * ImmutableMap#toImmutableMap(Function, Function)} from consumers of {@code ImmutableBiMap}.
    *
    * @throws UnsupportedOperationException always
-   * @deprecated Use {@link ImmutableBiMap#toImmutableBiMap}.
+   * @deprecated Use {@link ImmutableBiMap#toImmutableBiMap(Function, Function)}.
    * @since 33.2.0 (available since 21.0 in guava-jre)
    */
   @Deprecated
@@ -643,7 +645,7 @@ public abstract class ImmutableBiMap<K, V> extends ImmutableMap<K, V> implements
    * {@code ImmutableBiMap}.
    *
    * @throws UnsupportedOperationException always
-   * @deprecated
+   * @deprecated Merging values does not make sense for a {@code BiMap}.
    * @since 33.2.0 (available since 21.0 in guava-jre)
    */
   @Deprecated
@@ -658,5 +660,5 @@ public abstract class ImmutableBiMap<K, V> extends ImmutableMap<K, V> implements
     throw new UnsupportedOperationException();
   }
 
-  private static final long serialVersionUID = 0xdecaf;
+  @GwtIncompatible @J2ktIncompatible private static final long serialVersionUID = 0xdecaf;
 }
