@@ -26,6 +26,8 @@ import static java.util.Arrays.asList;
 import static java.util.Objects.requireNonNull;
 
 import com.google.common.annotations.GwtCompatible;
+import com.google.common.annotations.GwtIncompatible;
+import com.google.common.annotations.J2ktIncompatible;
 import com.google.common.base.Objects;
 import com.google.common.base.Predicate;
 import com.google.common.base.Predicates;
@@ -33,6 +35,7 @@ import com.google.common.collect.Multiset.Entry;
 import com.google.common.math.IntMath;
 import com.google.common.primitives.Ints;
 import com.google.errorprone.annotations.CanIgnoreReturnValue;
+import com.google.errorprone.annotations.InlineMe;
 import com.google.errorprone.annotations.concurrent.LazyInit;
 import java.io.Serializable;
 import java.util.Arrays;
@@ -46,8 +49,7 @@ import java.util.function.Function;
 import java.util.function.Supplier;
 import java.util.function.ToIntFunction;
 import java.util.stream.Collector;
-import javax.annotation.CheckForNull;
-import org.checkerframework.checker.nullness.qual.Nullable;
+import org.jspecify.annotations.Nullable;
 
 /**
  * Provides static utility methods for creating and working with {@link Multiset} instances.
@@ -62,7 +64,6 @@ import org.checkerframework.checker.nullness.qual.Nullable;
  * @since 2.0
  */
 @GwtCompatible
-@ElementTypesAreNonnullByDefault
 public final class Multisets {
   private Multisets() {}
 
@@ -119,6 +120,9 @@ public final class Multisets {
    * @deprecated no need to use this
    * @since 10.0
    */
+  @InlineMe(
+      replacement = "checkNotNull(multiset)",
+      staticImports = "com.google.common.base.Preconditions.checkNotNull")
   @Deprecated
   public static <E> Multiset<E> unmodifiableMultiset(ImmutableMultiset<E> multiset) {
     return checkNotNull(multiset);
@@ -139,7 +143,7 @@ public final class Multisets {
       return (Multiset<E>) delegate;
     }
 
-    @LazyInit @CheckForNull transient Set<E> elementSet;
+    @LazyInit transient @Nullable Set<E> elementSet;
 
     Set<E> createElementSet() {
       return Collections.<E>unmodifiableSet(delegate.elementSet());
@@ -151,7 +155,7 @@ public final class Multisets {
       return (es == null) ? elementSet = createElementSet() : es;
     }
 
-    @LazyInit @CheckForNull transient Set<Multiset.Entry<E>> entrySet;
+    @LazyInit transient @Nullable Set<Multiset.Entry<E>> entrySet;
 
     @SuppressWarnings("unchecked")
     @Override
@@ -185,12 +189,12 @@ public final class Multisets {
     }
 
     @Override
-    public boolean remove(@CheckForNull Object element) {
+    public boolean remove(@Nullable Object element) {
       throw new UnsupportedOperationException();
     }
 
     @Override
-    public int remove(@CheckForNull Object element, int occurrences) {
+    public int remove(@Nullable Object element, int occurrences) {
       throw new UnsupportedOperationException();
     }
 
@@ -219,7 +223,7 @@ public final class Multisets {
       throw new UnsupportedOperationException();
     }
 
-    private static final long serialVersionUID = 0;
+    @GwtIncompatible @J2ktIncompatible private static final long serialVersionUID = 0;
   }
 
   /**
@@ -274,12 +278,11 @@ public final class Multisets {
       return count;
     }
 
-    @CheckForNull
-    public ImmutableEntry<E> nextInBucket() {
+    public @Nullable ImmutableEntry<E> nextInBucket() {
       return null;
     }
 
-    private static final long serialVersionUID = 0;
+    @GwtIncompatible @J2ktIncompatible private static final long serialVersionUID = 0;
   }
 
   /**
@@ -345,14 +348,7 @@ public final class Multisets {
 
     @Override
     Set<Entry<E>> createEntrySet() {
-      return Sets.filter(
-          unfiltered.entrySet(),
-          new Predicate<Entry<E>>() {
-            @Override
-            public boolean apply(Entry<E> entry) {
-              return predicate.apply(entry.getElement());
-            }
-          });
+      return Sets.filter(unfiltered.entrySet(), entry -> predicate.apply(entry.getElement()));
     }
 
     @Override
@@ -361,7 +357,7 @@ public final class Multisets {
     }
 
     @Override
-    public int count(@CheckForNull Object element) {
+    public int count(@Nullable Object element) {
       int count = unfiltered.count(element);
       if (count > 0) {
         @SuppressWarnings("unchecked") // element is equal to an E
@@ -379,7 +375,7 @@ public final class Multisets {
     }
 
     @Override
-    public int remove(@CheckForNull Object element, int occurrences) {
+    public int remove(@Nullable Object element, int occurrences) {
       checkNonnegative(occurrences, "occurrences");
       if (occurrences == 0) {
         return count(element);
@@ -414,13 +410,13 @@ public final class Multisets {
    * @since 14.0
    */
   public static <E extends @Nullable Object> Multiset<E> union(
-      final Multiset<? extends E> multiset1, final Multiset<? extends E> multiset2) {
+      Multiset<? extends E> multiset1, Multiset<? extends E> multiset2) {
     checkNotNull(multiset1);
     checkNotNull(multiset2);
 
     return new ViewMultiset<E>() {
       @Override
-      public boolean contains(@CheckForNull Object element) {
+      public boolean contains(@Nullable Object element) {
         return multiset1.contains(element) || multiset2.contains(element);
       }
 
@@ -430,7 +426,7 @@ public final class Multisets {
       }
 
       @Override
-      public int count(@CheckForNull Object element) {
+      public int count(@Nullable Object element) {
         return max(multiset1.count(element), multiset2.count(element));
       }
 
@@ -446,13 +442,12 @@ public final class Multisets {
 
       @Override
       Iterator<Entry<E>> entryIterator() {
-        final Iterator<? extends Entry<? extends E>> iterator1 = multiset1.entrySet().iterator();
-        final Iterator<? extends Entry<? extends E>> iterator2 = multiset2.entrySet().iterator();
+        Iterator<? extends Entry<? extends E>> iterator1 = multiset1.entrySet().iterator();
+        Iterator<? extends Entry<? extends E>> iterator2 = multiset2.entrySet().iterator();
         // TODO(lowasser): consider making the entries live views
         return new AbstractIterator<Entry<E>>() {
           @Override
-          @CheckForNull
-          protected Entry<E> computeNext() {
+          protected @Nullable Entry<E> computeNext() {
             if (iterator1.hasNext()) {
               Entry<? extends E> entry1 = iterator1.next();
               E element = entry1.getElement();
@@ -486,13 +481,13 @@ public final class Multisets {
    * @since 2.0
    */
   public static <E extends @Nullable Object> Multiset<E> intersection(
-      final Multiset<E> multiset1, final Multiset<?> multiset2) {
+      Multiset<E> multiset1, Multiset<?> multiset2) {
     checkNotNull(multiset1);
     checkNotNull(multiset2);
 
     return new ViewMultiset<E>() {
       @Override
-      public int count(@CheckForNull Object element) {
+      public int count(@Nullable Object element) {
         int count1 = multiset1.count(element);
         return (count1 == 0) ? 0 : min(count1, multiset2.count(element));
       }
@@ -509,12 +504,11 @@ public final class Multisets {
 
       @Override
       Iterator<Entry<E>> entryIterator() {
-        final Iterator<Entry<E>> iterator1 = multiset1.entrySet().iterator();
+        Iterator<Entry<E>> iterator1 = multiset1.entrySet().iterator();
         // TODO(lowasser): consider making the entries live views
         return new AbstractIterator<Entry<E>>() {
           @Override
-          @CheckForNull
-          protected Entry<E> computeNext() {
+          protected @Nullable Entry<E> computeNext() {
             while (iterator1.hasNext()) {
               Entry<E> entry1 = iterator1.next();
               E element = entry1.getElement();
@@ -543,14 +537,14 @@ public final class Multisets {
    * @since 14.0
    */
   public static <E extends @Nullable Object> Multiset<E> sum(
-      final Multiset<? extends E> multiset1, final Multiset<? extends E> multiset2) {
+      Multiset<? extends E> multiset1, Multiset<? extends E> multiset2) {
     checkNotNull(multiset1);
     checkNotNull(multiset2);
 
     // TODO(lowasser): consider making the entries live views
     return new ViewMultiset<E>() {
       @Override
-      public boolean contains(@CheckForNull Object element) {
+      public boolean contains(@Nullable Object element) {
         return multiset1.contains(element) || multiset2.contains(element);
       }
 
@@ -565,7 +559,7 @@ public final class Multisets {
       }
 
       @Override
-      public int count(@CheckForNull Object element) {
+      public int count(@Nullable Object element) {
         return multiset1.count(element) + multiset2.count(element);
       }
 
@@ -581,12 +575,11 @@ public final class Multisets {
 
       @Override
       Iterator<Entry<E>> entryIterator() {
-        final Iterator<? extends Entry<? extends E>> iterator1 = multiset1.entrySet().iterator();
-        final Iterator<? extends Entry<? extends E>> iterator2 = multiset2.entrySet().iterator();
+        Iterator<? extends Entry<? extends E>> iterator1 = multiset1.entrySet().iterator();
+        Iterator<? extends Entry<? extends E>> iterator2 = multiset2.entrySet().iterator();
         return new AbstractIterator<Entry<E>>() {
           @Override
-          @CheckForNull
-          protected Entry<E> computeNext() {
+          protected @Nullable Entry<E> computeNext() {
             if (iterator1.hasNext()) {
               Entry<? extends E> entry1 = iterator1.next();
               E element = entry1.getElement();
@@ -620,14 +613,14 @@ public final class Multisets {
    * @since 14.0
    */
   public static <E extends @Nullable Object> Multiset<E> difference(
-      final Multiset<E> multiset1, final Multiset<?> multiset2) {
+      Multiset<E> multiset1, Multiset<?> multiset2) {
     checkNotNull(multiset1);
     checkNotNull(multiset2);
 
     // TODO(lowasser): consider making the entries live views
     return new ViewMultiset<E>() {
       @Override
-      public int count(@CheckForNull Object element) {
+      public int count(@Nullable Object element) {
         int count1 = multiset1.count(element);
         return (count1 == 0) ? 0 : max(0, count1 - multiset2.count(element));
       }
@@ -639,11 +632,10 @@ public final class Multisets {
 
       @Override
       Iterator<E> elementIterator() {
-        final Iterator<Entry<E>> iterator1 = multiset1.entrySet().iterator();
+        Iterator<Entry<E>> iterator1 = multiset1.entrySet().iterator();
         return new AbstractIterator<E>() {
           @Override
-          @CheckForNull
-          protected E computeNext() {
+          protected @Nullable E computeNext() {
             while (iterator1.hasNext()) {
               Entry<E> entry1 = iterator1.next();
               E element = entry1.getElement();
@@ -658,11 +650,10 @@ public final class Multisets {
 
       @Override
       Iterator<Entry<E>> entryIterator() {
-        final Iterator<Entry<E>> iterator1 = multiset1.entrySet().iterator();
+        Iterator<Entry<E>> iterator1 = multiset1.entrySet().iterator();
         return new AbstractIterator<Entry<E>>() {
           @Override
-          @CheckForNull
-          protected Entry<E> computeNext() {
+          protected @Nullable Entry<E> computeNext() {
             while (iterator1.hasNext()) {
               Entry<E> entry1 = iterator1.next();
               E element = entry1.getElement();
@@ -759,11 +750,11 @@ public final class Multisets {
    * in {@code occurrencesToRemove}. However, this operation <i>is</i> equivalent to, albeit
    * sometimes more efficient than, the following:
    *
-   * <pre>{@code
+   * {@snippet :
    * for (E e : occurrencesToRemove) {
    *   multisetToModify.remove(e);
    * }
-   * }</pre>
+   * }
    *
    * @return {@code true} if {@code multisetToModify} was changed as a result of this operation
    * @since 18.0 (present in 10.0 with a requirement that the second parameter be a {@code
@@ -798,11 +789,11 @@ public final class Multisets {
    * in {@code occurrencesToRemove}. However, this operation <i>is</i> equivalent to, albeit
    * sometimes more efficient than, the following:
    *
-   * <pre>{@code
+   * {@snippet :
    * for (E e : occurrencesToRemove) {
    *   multisetToModify.remove(e);
    * }
-   * }</pre>
+   * }
    *
    * @return {@code true} if {@code multisetToModify} was changed as a result of this operation
    * @since 10.0 (missing in 18.0 when only the overload taking an {@code Iterable} was present)
@@ -839,7 +830,7 @@ public final class Multisets {
      * Multiset.Entry#equals}.
      */
     @Override
-    public boolean equals(@CheckForNull Object object) {
+    public boolean equals(@Nullable Object object) {
       if (object instanceof Multiset.Entry) {
         Multiset.Entry<?> that = (Multiset.Entry<?>) object;
         return this.getCount() == that.getCount()
@@ -873,7 +864,7 @@ public final class Multisets {
   }
 
   /** An implementation of {@link Multiset#equals}. */
-  static boolean equalsImpl(Multiset<?> multiset, @CheckForNull Object object) {
+  static boolean equalsImpl(Multiset<?> multiset, @Nullable Object object) {
     if (object == multiset) {
       return true;
     }
@@ -904,7 +895,7 @@ public final class Multisets {
     checkNotNull(self);
     checkNotNull(elements);
     if (elements instanceof Multiset) {
-      return addAllImpl(self, cast(elements));
+      return addAllImpl(self, (Multiset<? extends E>) elements);
     } else if (elements.isEmpty()) {
       return false;
     } else {
@@ -1014,7 +1005,7 @@ public final class Multisets {
     }
 
     @Override
-    public boolean contains(@CheckForNull Object o) {
+    public boolean contains(@Nullable Object o) {
       return multiset().contains(o);
     }
 
@@ -1032,7 +1023,7 @@ public final class Multisets {
     public abstract Iterator<E> iterator();
 
     @Override
-    public boolean remove(@CheckForNull Object o) {
+    public boolean remove(@Nullable Object o) {
       return multiset().remove(o, Integer.MAX_VALUE) > 0;
     }
 
@@ -1047,7 +1038,7 @@ public final class Multisets {
     abstract Multiset<E> multiset();
 
     @Override
-    public boolean contains(@CheckForNull Object o) {
+    public boolean contains(@Nullable Object o) {
       if (o instanceof Entry) {
         Entry<?> entry = (Entry<?>) o;
         if (entry.getCount() <= 0) {
@@ -1060,7 +1051,7 @@ public final class Multisets {
     }
 
     @Override
-    public boolean remove(@CheckForNull Object object) {
+    public boolean remove(@Nullable Object object) {
       if (object instanceof Multiset.Entry) {
         Entry<?> entry = (Entry<?>) object;
         Object element = entry.getElement();
@@ -1090,7 +1081,7 @@ public final class Multisets {
   static final class MultisetIteratorImpl<E extends @Nullable Object> implements Iterator<E> {
     private final Multiset<E> multiset;
     private final Iterator<Entry<E>> entryIterator;
-    @CheckForNull private Entry<E> currentEntry;
+    private @Nullable Entry<E> currentEntry;
 
     /** Count of subsequent elements equal to current element */
     private int laterCount;
@@ -1155,11 +1146,6 @@ public final class Multisets {
     return Ints.saturatedCast(size);
   }
 
-  /** Used to avoid http://bugs.sun.com/view_bug.do?bug_id=6558557 */
-  static <T extends @Nullable Object> Multiset<T> cast(Iterable<T> iterable) {
-    return (Multiset<T>) iterable;
-  }
-
   /**
    * Returns a copy of {@code multiset} as an {@link ImmutableMultiset} whose iteration order puts
    * the highest count first, with ties broken by the iteration order of the original multiset.
