@@ -37,8 +37,7 @@ import java.util.Comparator;
 import java.util.ConcurrentModificationException;
 import java.util.Iterator;
 import java.util.NoSuchElementException;
-import javax.annotation.CheckForNull;
-import org.checkerframework.checker.nullness.qual.Nullable;
+import org.jspecify.annotations.Nullable;
 
 /**
  * A multiset which maintains the ordering of its elements, according to either their natural order
@@ -58,7 +57,6 @@ import org.checkerframework.checker.nullness.qual.Nullable;
  * @since 2.0
  */
 @GwtCompatible(emulated = true)
-@ElementTypesAreNonnullByDefault
 public final class TreeMultiset<E extends @Nullable Object> extends AbstractSortedMultiset<E>
     implements Serializable {
 
@@ -92,7 +90,7 @@ public final class TreeMultiset<E extends @Nullable Object> extends AbstractSort
    */
   @SuppressWarnings("unchecked")
   public static <E extends @Nullable Object> TreeMultiset<E> create(
-      @CheckForNull Comparator<? super E> comparator) {
+      @Nullable Comparator<? super E> comparator) {
     return (comparator == null)
         ? new TreeMultiset<E>((Comparator) Ordering.natural())
         : new TreeMultiset<E>(comparator);
@@ -142,7 +140,7 @@ public final class TreeMultiset<E extends @Nullable Object> extends AbstractSort
       }
 
       @Override
-      long treeAggregate(@CheckForNull AvlNode<?> root) {
+      long treeAggregate(@Nullable AvlNode<?> root) {
         return (root == null) ? 0 : root.totalCount;
       }
     },
@@ -153,14 +151,14 @@ public final class TreeMultiset<E extends @Nullable Object> extends AbstractSort
       }
 
       @Override
-      long treeAggregate(@CheckForNull AvlNode<?> root) {
+      long treeAggregate(@Nullable AvlNode<?> root) {
         return (root == null) ? 0 : root.distinctElements;
       }
     };
 
     abstract int nodeAggregate(AvlNode<?> node);
 
-    abstract long treeAggregate(@CheckForNull AvlNode<?> root);
+    abstract long treeAggregate(@Nullable AvlNode<?> root);
   }
 
   private long aggregateForEntries(Aggregate aggr) {
@@ -175,7 +173,7 @@ public final class TreeMultiset<E extends @Nullable Object> extends AbstractSort
     return total;
   }
 
-  private long aggregateBelowRange(Aggregate aggr, @CheckForNull AvlNode<E> node) {
+  private long aggregateBelowRange(Aggregate aggr, @Nullable AvlNode<E> node) {
     if (node == null) {
       return 0;
     }
@@ -200,7 +198,7 @@ public final class TreeMultiset<E extends @Nullable Object> extends AbstractSort
     }
   }
 
-  private long aggregateAboveRange(Aggregate aggr, @CheckForNull AvlNode<E> node) {
+  private long aggregateAboveRange(Aggregate aggr, @Nullable AvlNode<E> node) {
     if (node == null) {
       return 0;
     }
@@ -235,12 +233,12 @@ public final class TreeMultiset<E extends @Nullable Object> extends AbstractSort
     return Ints.saturatedCast(aggregateForEntries(Aggregate.DISTINCT));
   }
 
-  static int distinctElements(@CheckForNull AvlNode<?> node) {
+  static int distinctElements(@Nullable AvlNode<?> node) {
     return (node == null) ? 0 : node.distinctElements;
   }
 
   @Override
-  public int count(@CheckForNull Object element) {
+  public int count(@Nullable Object element) {
     try {
       @SuppressWarnings("unchecked")
       E e = (E) element;
@@ -278,7 +276,7 @@ public final class TreeMultiset<E extends @Nullable Object> extends AbstractSort
 
   @CanIgnoreReturnValue
   @Override
-  public int remove(@CheckForNull Object element, int occurrences) {
+  public int remove(@Nullable Object element, int occurrences) {
     checkNonnegative(occurrences, "occurrences");
     if (occurrences == 0) {
       return count(element);
@@ -370,7 +368,7 @@ public final class TreeMultiset<E extends @Nullable Object> extends AbstractSort
     }
   }
 
-  private Entry<E> wrapEntry(final AvlNode<E> baseEntry) {
+  private Entry<E> wrapEntry(AvlNode<E> baseEntry) {
     return new Multisets.AbstractEntry<E>() {
       @Override
       @ParametricNullness
@@ -391,8 +389,7 @@ public final class TreeMultiset<E extends @Nullable Object> extends AbstractSort
   }
 
   /** Returns the first node in the tree that is in range. */
-  @CheckForNull
-  private AvlNode<E> firstNode() {
+  private @Nullable AvlNode<E> firstNode() {
     AvlNode<E> root = rootReference.get();
     if (root == null) {
       return null;
@@ -415,8 +412,7 @@ public final class TreeMultiset<E extends @Nullable Object> extends AbstractSort
     return (node == header || !range.contains(node.getElement())) ? null : node;
   }
 
-  @CheckForNull
-  private AvlNode<E> lastNode() {
+  private @Nullable AvlNode<E> lastNode() {
     AvlNode<E> root = rootReference.get();
     if (root == null) {
       return null;
@@ -447,8 +443,8 @@ public final class TreeMultiset<E extends @Nullable Object> extends AbstractSort
   @Override
   Iterator<Entry<E>> entryIterator() {
     return new Iterator<Entry<E>>() {
-      @CheckForNull AvlNode<E> current = firstNode();
-      @CheckForNull Entry<E> prevEntry;
+      @Nullable AvlNode<E> current = firstNode();
+      @Nullable Entry<E> prevEntry;
 
       @Override
       public boolean hasNext() {
@@ -490,8 +486,8 @@ public final class TreeMultiset<E extends @Nullable Object> extends AbstractSort
   @Override
   Iterator<Entry<E>> descendingEntryIterator() {
     return new Iterator<Entry<E>>() {
-      @CheckForNull AvlNode<E> current = lastNode();
-      @CheckForNull Entry<E> prevEntry = null;
+      @Nullable AvlNode<E> current = lastNode();
+      @Nullable Entry<E> prevEntry = null;
 
       @Override
       public boolean hasNext() {
@@ -553,14 +549,13 @@ public final class TreeMultiset<E extends @Nullable Object> extends AbstractSort
   }
 
   private static final class Reference<T> {
-    @CheckForNull private T value;
+    private @Nullable T value;
 
-    @CheckForNull
-    public T get() {
+    public @Nullable T get() {
       return value;
     }
 
-    public void checkAndSet(@CheckForNull T expected, @CheckForNull T newValue) {
+    public void checkAndSet(@Nullable T expected, @Nullable T newValue) {
       if (value != expected) {
         throw new ConcurrentModificationException();
       }
@@ -583,7 +578,7 @@ public final class TreeMultiset<E extends @Nullable Object> extends AbstractSort
      * Most code that operates on an AvlNode never operates on the header node. Such code can access
      * the elem field without a null check by calling getElement().
      */
-    @CheckForNull private final E elem;
+    private final @Nullable E elem;
 
     // elemCount is 0 iff this node has been deleted.
     private int elemCount;
@@ -591,8 +586,8 @@ public final class TreeMultiset<E extends @Nullable Object> extends AbstractSort
     private int distinctElements;
     private long totalCount;
     private int height;
-    @CheckForNull private AvlNode<E> left;
-    @CheckForNull private AvlNode<E> right;
+    private @Nullable AvlNode<E> left;
+    private @Nullable AvlNode<E> right;
     /*
      * pred and succ are nullable after construction, but we always call successor() to initialize
      * them immediately thereafter.
@@ -604,8 +599,8 @@ public final class TreeMultiset<E extends @Nullable Object> extends AbstractSort
      * To access these fields when you know that they are not null, call the pred() and succ()
      * methods, which perform null checks before returning the fields.
      */
-    @CheckForNull private AvlNode<E> pred;
-    @CheckForNull private AvlNode<E> succ;
+    private @Nullable AvlNode<E> pred;
+    private @Nullable AvlNode<E> succ;
 
     AvlNode(@ParametricNullness E elem, int elemCount) {
       checkArgument(elemCount > 0);
@@ -645,6 +640,7 @@ public final class TreeMultiset<E extends @Nullable Object> extends AbstractSort
       }
     }
 
+    @CanIgnoreReturnValue
     private AvlNode<E> addRightChild(@ParametricNullness E e, int count) {
       right = new AvlNode<>(e, count);
       successor(this, right, succ());
@@ -654,6 +650,7 @@ public final class TreeMultiset<E extends @Nullable Object> extends AbstractSort
       return this;
     }
 
+    @CanIgnoreReturnValue
     private AvlNode<E> addLeftChild(@ParametricNullness E e, int count) {
       left = new AvlNode<>(e, count);
       successor(pred(), left, this);
@@ -709,8 +706,7 @@ public final class TreeMultiset<E extends @Nullable Object> extends AbstractSort
       return this;
     }
 
-    @CheckForNull
-    AvlNode<E> remove(
+    @Nullable AvlNode<E> remove(
         Comparator<? super E> comparator, @ParametricNullness E e, int count, int[] result) {
       int cmp = comparator.compare(e, getElement());
       if (cmp < 0) {
@@ -762,8 +758,7 @@ public final class TreeMultiset<E extends @Nullable Object> extends AbstractSort
       }
     }
 
-    @CheckForNull
-    AvlNode<E> setCount(
+    @Nullable AvlNode<E> setCount(
         Comparator<? super E> comparator, @ParametricNullness E e, int count, int[] result) {
       int cmp = comparator.compare(e, getElement());
       if (cmp < 0) {
@@ -812,8 +807,7 @@ public final class TreeMultiset<E extends @Nullable Object> extends AbstractSort
       return this;
     }
 
-    @CheckForNull
-    AvlNode<E> setCount(
+    @Nullable AvlNode<E> setCount(
         Comparator<? super E> comparator,
         @ParametricNullness E e,
         int expectedCount,
@@ -876,8 +870,7 @@ public final class TreeMultiset<E extends @Nullable Object> extends AbstractSort
       return this;
     }
 
-    @CheckForNull
-    private AvlNode<E> deleteMe() {
+    private @Nullable AvlNode<E> deleteMe() {
       int oldElemCount = this.elemCount;
       this.elemCount = 0;
       successor(pred(), succ());
@@ -904,8 +897,7 @@ public final class TreeMultiset<E extends @Nullable Object> extends AbstractSort
     }
 
     // Removes the minimum node from this subtree to be reused elsewhere
-    @CheckForNull
-    private AvlNode<E> removeMin(AvlNode<E> node) {
+    private @Nullable AvlNode<E> removeMin(AvlNode<E> node) {
       if (left == null) {
         return right;
       } else {
@@ -917,8 +909,7 @@ public final class TreeMultiset<E extends @Nullable Object> extends AbstractSort
     }
 
     // Removes the maximum node from this subtree to be reused elsewhere
-    @CheckForNull
-    private AvlNode<E> removeMax(AvlNode<E> node) {
+    private @Nullable AvlNode<E> removeMax(AvlNode<E> node) {
       if (right == null) {
         return left;
       } else {
@@ -994,16 +985,16 @@ public final class TreeMultiset<E extends @Nullable Object> extends AbstractSort
       return newTop;
     }
 
-    private static long totalCount(@CheckForNull AvlNode<?> node) {
+    private static long totalCount(@Nullable AvlNode<?> node) {
       return (node == null) ? 0 : node.totalCount;
     }
 
-    private static int height(@CheckForNull AvlNode<?> node) {
+    private static int height(@Nullable AvlNode<?> node) {
       return (node == null) ? 0 : node.height;
     }
 
-    @CheckForNull
-    private AvlNode<E> ceiling(Comparator<? super E> comparator, @ParametricNullness E e) {
+    private @Nullable AvlNode<E> ceiling(
+        Comparator<? super E> comparator, @ParametricNullness E e) {
       int cmp = comparator.compare(e, getElement());
       if (cmp < 0) {
         return (left == null) ? this : MoreObjects.firstNonNull(left.ceiling(comparator, e), this);
@@ -1014,8 +1005,7 @@ public final class TreeMultiset<E extends @Nullable Object> extends AbstractSort
       }
     }
 
-    @CheckForNull
-    private AvlNode<E> floor(Comparator<? super E> comparator, @ParametricNullness E e) {
+    private @Nullable AvlNode<E> floor(Comparator<? super E> comparator, @ParametricNullness E e) {
       int cmp = comparator.compare(e, getElement());
       if (cmp > 0) {
         return (right == null) ? this : MoreObjects.firstNonNull(right.floor(comparator, e), this);
@@ -1072,8 +1062,8 @@ public final class TreeMultiset<E extends @Nullable Object> extends AbstractSort
   }
 
   @J2ktIncompatible
-  @GwtIncompatible // java.io.ObjectInputStream
-  private void readObject(ObjectInputStream stream) throws IOException, ClassNotFoundException {
+  @GwtIncompatible
+    private void readObject(ObjectInputStream stream) throws IOException, ClassNotFoundException {
     stream.defaultReadObject();
     @SuppressWarnings("unchecked")
     // reading data stored by writeObject
@@ -1089,7 +1079,5 @@ public final class TreeMultiset<E extends @Nullable Object> extends AbstractSort
     Serialization.populateMultiset(this, stream);
   }
 
-  @GwtIncompatible // not needed in emulated source
-  @J2ktIncompatible
-  private static final long serialVersionUID = 1;
+  @GwtIncompatible @J2ktIncompatible private static final long serialVersionUID = 1;
 }
