@@ -40,8 +40,7 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.function.Consumer;
 import java.util.stream.Stream;
-import javax.annotation.CheckForNull;
-import org.checkerframework.checker.nullness.qual.Nullable;
+import org.jspecify.annotations.Nullable;
 
 /**
  * A readable source of characters, such as a text file. Unlike a {@link Reader}, a {@code
@@ -84,7 +83,6 @@ import org.checkerframework.checker.nullness.qual.Nullable;
  */
 @J2ktIncompatible
 @GwtIncompatible
-@ElementTypesAreNonnullByDefault
 public abstract class CharSource {
 
   /** Constructor for use by subclasses. */
@@ -145,13 +143,13 @@ public abstract class CharSource {
    *
    * <p>The caller is responsible for ensuring that the returned stream is closed. For example:
    *
-   * <pre>{@code
+   * {@snippet :
    * try (Stream<String> lines = source.lines()) {
    *   lines.map(...)
    *      .filter(...)
    *      .forEach(...);
    * }
-   * }</pre>
+   * }
    *
    * @throws IOException if an I/O error occurs while opening the stream
    * @since 33.4.0 (but since 22.0 in the JRE flavor)
@@ -315,8 +313,7 @@ public abstract class CharSource {
    *
    * @throws IOException if an I/O error occurs while reading from this source
    */
-  @CheckForNull
-  public String readFirstLine() throws IOException {
+  public @Nullable String readFirstLine() throws IOException {
     Closer closer = Closer.create();
     try {
       BufferedReader reader = closer.register(openBufferedStream());
@@ -589,8 +586,7 @@ public abstract class CharSource {
         Iterator<String> lines = LINE_SPLITTER.split(seq).iterator();
 
         @Override
-        @CheckForNull
-        protected String computeNext() {
+        protected @Nullable String computeNext() {
           if (lines.hasNext()) {
             String next = lines.next();
             // skip last line if it's empty
@@ -612,8 +608,7 @@ public abstract class CharSource {
     }
 
     @Override
-    @CheckForNull
-    public String readFirstLine() {
+    public @Nullable String readFirstLine() {
       Iterator<String> lines = linesIterator();
       return lines.hasNext() ? lines.next() : null;
     }
