@@ -44,6 +44,7 @@ import java.util.TreeMap;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 import junit.framework.TestCase;
+import org.jspecify.annotations.NullMarked;
 import org.junit.Test;
 
 /**
@@ -105,7 +106,7 @@ import org.junit.Test;
 @GwtIncompatible
 @J2ktIncompatible
 @J2ObjCIncompatible // com.google.common.reflect.ClassPath
-@ElementTypesAreNonnullByDefault
+@NullMarked
 public abstract class AbstractPackageSanityTests extends TestCase {
 
   /**
