@@ -28,7 +28,8 @@ import com.google.common.collect.Table.Cell;
 import com.google.common.testing.CollectorTester;
 import com.google.common.testing.SerializableTester;
 import java.util.stream.Collector;
-import org.checkerframework.checker.nullness.qual.Nullable;
+import org.jspecify.annotations.NullMarked;
+import org.jspecify.annotations.Nullable;
 
 /**
  * Tests common methods in {@link ImmutableTable}
@@ -36,7 +37,7 @@ import org.checkerframework.checker.nullness.qual.Nullable;
  * @author Gregory Kick
  */
 @GwtCompatible(emulated = true)
-@ElementTypesAreNonnullByDefault
+@NullMarked
 public class ImmutableTableTest extends AbstractTableReadTest<Character> {
   @Override
   protected Table<String, Integer, Character> create(@Nullable Object... data) {
@@ -44,7 +45,7 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
     for (int i = 0; i < data.length; i = i + 3) {
       builder.put((String) data[i], (Integer) data[i + 1], (Character) data[i + 2]);
     }
-    return builder.build();
+    return builder.buildOrThrow();
   }
 
   // The bulk of the toImmutableTable tests can be found in TableCollectorsTest.
@@ -70,8 +71,8 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
 
   public void testBuilder() {
     ImmutableTable.Builder<Character, Integer, String> builder = new ImmutableTable.Builder<>();
-    assertEquals(ImmutableTable.of(), builder.build());
-    assertEquals(ImmutableTable.of('a', 1, "foo"), builder.put('a', 1, "foo").build());
+    assertEquals(ImmutableTable.of(), builder.buildOrThrow());
+    assertEquals(ImmutableTable.of('a', 1, "foo"), builder.put('a', 1, "foo").buildOrThrow());
     Table<Character, Integer, String> expectedTable = HashBasedTable.create();
     expectedTable.put('a', 1, "foo");
     expectedTable.put('b', 1, "bar");
@@ -79,13 +80,13 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
     Table<Character, Integer, String> otherTable = HashBasedTable.create();
     otherTable.put('b', 1, "bar");
     otherTable.put('a', 2, "baz");
-    assertEquals(expectedTable, builder.putAll(otherTable).build());
+    assertEquals(expectedTable, builder.putAll(otherTable).buildOrThrow());
   }
 
   public void testBuilder_withImmutableCell() {
     ImmutableTable.Builder<Character, Integer, String> builder = new ImmutableTable.Builder<>();
     assertEquals(
-        ImmutableTable.of('a', 1, "foo"), builder.put(immutableCell('a', 1, "foo")).build());
+        ImmutableTable.of('a', 1, "foo"), builder.put(immutableCell('a', 1, "foo")).buildOrThrow());
   }
 
   public void testBuilder_withImmutableCellAndNullContents() {
@@ -132,7 +133,7 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
     holder.string = "bar";
 
     // Make sure it uses the original value.
-    assertEquals(ImmutableTable.of('K', 42, "foo"), builder.build());
+    assertEquals(ImmutableTable.of('K', 42, "foo"), builder.buildOrThrow());
   }
 
   public void testBuilder_noDuplicates() {
@@ -140,7 +141,7 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
         new ImmutableTable.Builder<Character, Integer, String>()
             .put('a', 1, "foo")
             .put('a', 1, "bar");
-    assertThrows(IllegalArgumentException.class, () -> builder.build());
+    assertThrows(IllegalArgumentException.class, () -> builder.buildOrThrow());
   }
 
   public void testBuilder_noNulls() {
@@ -155,7 +156,7 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
     assertEquals(original, copy);
     validateViewOrdering(original, copy);
 
-    Table<R, C, V> built = ImmutableTable.<R, C, V>builder().putAll(original).build();
+    Table<R, C, V> built = ImmutableTable.<R, C, V>builder().putAll(original).buildOrThrow();
     assertEquals(original, built);
     validateViewOrdering(original, built);
   }
@@ -218,7 +219,7 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
             .orderRowsBy(Ordering.natural())
             .orderColumnsBy(Ordering.natural())
             .putAll(table)
-            .build();
+            .buildOrThrow();
     assertThat(copy.rowKeySet()).containsExactly('a', 'b').inOrder();
     assertThat(copy.columnKeySet()).containsExactly(1, 2).inOrder();
     assertThat(copy.values()).containsExactly("baz", "bar", "foo").inOrder();
@@ -238,7 +239,7 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
     builder.put('e', 3, "tub");
     builder.put('r', 4, "foo");
     builder.put('x', 5, "bar");
-    Table<Character, Integer, String> table = builder.build();
+    Table<Character, Integer, String> table = builder.buildOrThrow();
     assertThat(table.rowKeySet()).containsExactly('b', 'c', 'e', 'r', 'x').inOrder();
     assertThat(table.columnKeySet()).containsExactly(0, 1, 2, 3, 4, 5, 7).inOrder();
     assertThat(table.values())
@@ -260,7 +261,7 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
     builder.put('a', 3, "foo");
     builder.put('a', 2, "bar");
     builder.put('a', 1, "baz");
-    Table<Character, Integer, String> table = builder.build();
+    Table<Character, Integer, String> table = builder.buildOrThrow();
     assertThat(table.rowKeySet()).containsExactly('a', 'b', 'c').inOrder();
     assertThat(table.columnKeySet()).containsExactly(1, 2, 3).inOrder();
     assertThat(table.values())
@@ -282,7 +283,7 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
     builder.put('e', 3, "tub");
     builder.put('r', 4, "foo");
     builder.put('x', 5, "bar");
-    Table<Character, Integer, String> table = builder.build();
+    Table<Character, Integer, String> table = builder.buildOrThrow();
     assertThat(table.rowKeySet()).containsExactly('b', 'c', 'e', 'r', 'x').inOrder();
     assertThat(table.column(5).keySet()).containsExactly('e', 'x').inOrder();
   }
@@ -298,7 +299,7 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
     builder.put('a', 3, "foo");
     builder.put('a', 2, "bar");
     builder.put('a', 1, "baz");
-    Table<Character, Integer, String> table = builder.build();
+    Table<Character, Integer, String> table = builder.buildOrThrow();
     assertThat(table.rowKeySet()).containsExactly('a', 'b', 'c').inOrder();
     assertThat(table.column(1).keySet()).containsExactly('a', 'b', 'c').inOrder();
   }
@@ -315,7 +316,7 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
     builder.put('e', 3, "tub");
     builder.put('r', 4, "foo");
     builder.put('x', 5, "bar");
-    Table<Character, Integer, String> table = builder.build();
+    Table<Character, Integer, String> table = builder.buildOrThrow();
     assertThat(table.columnKeySet()).containsExactly(0, 1, 2, 3, 4, 5, 7).inOrder();
     assertThat(table.row('c').keySet()).containsExactly(0, 3).inOrder();
   }
@@ -331,7 +332,7 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
     builder.put('a', 3, "foo");
     builder.put('a', 2, "bar");
     builder.put('a', 1, "baz");
-    Table<Character, Integer, String> table = builder.build();
+    Table<Character, Integer, String> table = builder.buildOrThrow();
     assertThat(table.columnKeySet()).containsExactly(1, 2, 3).inOrder();
     assertThat(table.row('c').keySet()).containsExactly(1, 2, 3).inOrder();
   }
@@ -349,7 +350,7 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
     builder.put('b', 2, "foo");
     builder.put('b', 1, "bar");
     builder.put('a', 2, "baz");
-    Table<Character, Integer, String> table = builder.build();
+    Table<Character, Integer, String> table = builder.buildOrThrow();
     assertThat(table).isInstanceOf(DenseImmutableTable.class);
     validateReserialization(table);
   }
@@ -360,7 +361,7 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
     builder.put('b', 2, "foo");
     builder.put('b', 1, "bar");
     builder.put('a', 2, "baz");
-    Table<Character, Integer, String> table = builder.build();
+    Table<Character, Integer, String> table = builder.buildOrThrow();
     assertThat(table).isInstanceOf(DenseImmutableTable.class);
     validateReserialization(table);
   }
@@ -371,7 +372,7 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
     builder.put('b', 2, "foo");
     builder.put('b', 1, "bar");
     builder.put('a', 2, "baz");
-    Table<Character, Integer, String> table = builder.build();
+    Table<Character, Integer, String> table = builder.buildOrThrow();
     assertThat(table).isInstanceOf(DenseImmutableTable.class);
     validateReserialization(table);
   }
@@ -383,7 +384,7 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
     builder.put('b', 2, "foo");
     builder.put('b', 1, "bar");
     builder.put('a', 2, "baz");
-    Table<Character, Integer, String> table = builder.build();
+    Table<Character, Integer, String> table = builder.buildOrThrow();
     assertThat(table).isInstanceOf(DenseImmutableTable.class);
     validateReserialization(table);
   }
@@ -395,7 +396,7 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
     builder.put('a', 2, "baz");
     builder.put('c', 3, "cat");
     builder.put('d', 4, "dog");
-    Table<Character, Integer, String> table = builder.build();
+    Table<Character, Integer, String> table = builder.buildOrThrow();
     assertThat(table).isInstanceOf(SparseImmutableTable.class);
     validateReserialization(table);
   }
@@ -408,7 +409,7 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
     builder.put('a', 2, "baz");
     builder.put('c', 3, "cat");
     builder.put('d', 4, "dog");
-    Table<Character, Integer, String> table = builder.build();
+    Table<Character, Integer, String> table = builder.buildOrThrow();
     assertThat(table).isInstanceOf(SparseImmutableTable.class);
     validateReserialization(table);
   }
@@ -421,7 +422,7 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
     builder.put('a', 2, "baz");
     builder.put('c', 3, "cat");
     builder.put('d', 4, "dog");
-    Table<Character, Integer, String> table = builder.build();
+    Table<Character, Integer, String> table = builder.buildOrThrow();
     assertThat(table).isInstanceOf(SparseImmutableTable.class);
     validateReserialization(table);
   }
@@ -435,7 +436,7 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
     builder.put('a', 2, "baz");
     builder.put('c', 3, "cat");
     builder.put('d', 4, "dog");
-    Table<Character, Integer, String> table = builder.build();
+    Table<Character, Integer, String> table = builder.buildOrThrow();
     assertThat(table).isInstanceOf(SparseImmutableTable.class);
     validateReserialization(table);
   }
@@ -457,6 +458,6 @@ public class ImmutableTableTest extends AbstractTableReadTest<Character> {
       builder.put(i, 0, "foo");
       builder.put(0, i, "bar");
     }
-    assertTrue(builder.build() instanceof SparseImmutableTable);
+    assertTrue(builder.buildOrThrow() instanceof SparseImmutableTable);
   }
 }
