@@ -76,7 +76,8 @@ import java.util.function.BiPredicate;
 import java.util.stream.Collector;
 import java.util.stream.Stream;
 import junit.framework.TestCase;
-import org.checkerframework.checker.nullness.qual.Nullable;
+import org.jspecify.annotations.NullMarked;
+import org.jspecify.annotations.Nullable;
 
 /**
  * Unit test for {@code Multimaps}.
@@ -84,7 +85,7 @@ import org.checkerframework.checker.nullness.qual.Nullable;
  * @author Jared Levy
  */
 @GwtCompatible(emulated = true)
-@ElementTypesAreNonnullByDefault
+@NullMarked
 public class MultimapsTest extends TestCase {
 
   private static final Comparator<Integer> INT_COMPARATOR =
@@ -151,7 +152,7 @@ public class MultimapsTest extends TestCase {
         .expectCollects(filled, "banana", "apple", "carrot", "asparagus", "cherry");
   }
 
-  @SuppressWarnings("deprecation")
+  @SuppressWarnings({"deprecation", "InlineMeInliner"}) // test of a deprecated method
   public void testUnmodifiableListMultimapShortCircuit() {
     ListMultimap<String, Integer> mod = ArrayListMultimap.create();
     ListMultimap<String, Integer> unmod = Multimaps.unmodifiableListMultimap(mod);
@@ -164,7 +165,7 @@ public class MultimapsTest extends TestCase {
         immutable, Multimaps.unmodifiableListMultimap((ListMultimap<String, Integer>) immutable));
   }
 
-  @SuppressWarnings("deprecation")
+  @SuppressWarnings({"deprecation", "InlineMeInliner"}) // test of a deprecated method
   public void testUnmodifiableSetMultimapShortCircuit() {
     SetMultimap<String, Integer> mod = HashMultimap.create();
     SetMultimap<String, Integer> unmod = Multimaps.unmodifiableSetMultimap(mod);
@@ -177,7 +178,7 @@ public class MultimapsTest extends TestCase {
         immutable, Multimaps.unmodifiableSetMultimap((SetMultimap<String, Integer>) immutable));
   }
 
-  @SuppressWarnings("deprecation")
+  @SuppressWarnings({"deprecation", "InlineMeInliner"}) // test of a deprecated method
   public void testUnmodifiableMultimapShortCircuit() {
     Multimap<String, Integer> mod = HashMultimap.create();
     Multimap<String, Integer> unmod = Multimaps.unmodifiableMultimap(mod);
@@ -613,11 +614,16 @@ public class MultimapsTest extends TestCase {
 
   private static class QueueSupplier extends CountingSupplier<Queue<Integer>> {
     @Override
+    /*
+     * We need a Queue that implements equals() for the equality tests we perform after
+     * reserializing the multimap.
+     */
+    @SuppressWarnings("JdkObsolete")
     public Queue<Integer> getImpl() {
       return new LinkedList<>();
     }
 
-    private static final long serialVersionUID = 0;
+    @GwtIncompatible @J2ktIncompatible private static final long serialVersionUID = 0;
   }
 
   public void testNewMultimapWithCollectionRejectingNegativeElements() {
@@ -657,7 +663,7 @@ public class MultimapsTest extends TestCase {
   }
 
   public void testNewMultimap() {
-    // The ubiquitous EnumArrayBlockingQueueMultimap
+    // The ubiquitous EnumLinkedListMultimap
     CountingSupplier<Queue<Integer>> factory = new QueueSupplier();
 
     Map<Color, Collection<Integer>> map = Maps.newEnumMap(Color.class);
@@ -711,7 +717,7 @@ public class MultimapsTest extends TestCase {
       return new LinkedList<>();
     }
 
-    private static final long serialVersionUID = 0;
+    @GwtIncompatible @J2ktIncompatible private static final long serialVersionUID = 0;
   }
 
   public void testNewListMultimap() {
@@ -747,7 +753,7 @@ public class MultimapsTest extends TestCase {
       return new HashSet<>(4);
     }
 
-    private static final long serialVersionUID = 0;
+    @GwtIncompatible @J2ktIncompatible private static final long serialVersionUID = 0;
   }
 
   public void testNewSetMultimap() {
@@ -779,7 +785,7 @@ public class MultimapsTest extends TestCase {
       return Sets.newTreeSet(INT_COMPARATOR);
     }
 
-    private static final long serialVersionUID = 0;
+    @GwtIncompatible @J2ktIncompatible private static final long serialVersionUID = 0;
   }
 
   public void testNewSortedSetMultimap() {
