@@ -28,12 +28,14 @@ import com.google.common.collect.ImmutableSet;
 import java.util.Collections;
 import java.util.Optional;
 import java.util.Set;
+import org.jspecify.annotations.NullUnmarked;
 import org.junit.After;
 import org.junit.Test;
 
 /**
  * Abstract base class for testing directed {@link Network} implementations defined in this package.
  */
+@NullUnmarked
 public abstract class AbstractStandardDirectedNetworkTest extends AbstractNetworkTest {
 
   @After
